/**
 * Autor 			: Alexandre Correia - alexandrecorreia@celepar.pr.gov.br
 * Data 			: 00/00/0000
 * Caso de Teste	: EL-941 : Adicionar compromisso Com Alarme
 * 
 * Descrio do Processo de Teste Cadastro no TestLink - http://testlink.expressolivre.org/ 
 * 
 * AES DO PASSO
 *	P01. Usurio informa um ttulo para o compromisso;
 *	P02. Usurio seleciona na opo alarme, o tempo que deseja ser avisado previamente da ocorrncia do compromisso
 *	P03. Usurio clica na opo para salvar o compromisso;
 *	P04. Sistema salva o compromisso e retorna para a tela da agenda de compromissos utilizando a visualizao padro configurada nas preferncias do Usurio
 *	P05. Sistema exibe o compromisso no dia selecionado pelo usurio mostrando o horrio inicial e final, o ttulo do compromisso, descrio e local alm de um smbolos indicando que esse compromisso  evento nico, que tem apenas um participante e que esse compromisso foi configurado para disparar um alarme
 *	P06. Sistema ir mandar uma mensagem para o Usurio sobre o incio do compromisso, quando o momento informado em P02 chegar
 */

package br.gov.serpro.cte.agenda.casoteste;

import java.util.GregorianCalendar;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import br.gov.serpro.cte.agenda.Objetos.AdicionarCompromissoEL941.Campo;
import br.gov.serpro.cte.agenda.Objetos.AdicionarCompromissoEL941.Valor;
import br.gov.serpro.cte.connection.DAOSelenium;
import br.gov.serpro.cte.connection.LoginExpresso;

import com.thoughtworks.selenium.SeleneseTestCase;

public class Test_EL_941_AdicionarCompromissoComAlarme extends SeleneseTestCase
{
	@Before
	public void setUp() throws Exception
	{
		String url			= "https://cte.serpro.gov.br";
		DAOSelenium conn	= new DAOSelenium( "localhost", 4444, "*pifirefox", url);
		selenium			= conn.newConnection();
	}
	@Test
	public void testa()
	{
		// Logando No Expresso
		selenium.open("/login.php");
		selenium.type("user", LoginExpresso.USER_EXPRESSO.getValue());
		selenium.type("passwd", LoginExpresso.PASSWORD_EXPRESSO.getValue());
		selenium.click("submitit");
		selenium.waitForPageToLoad("30000");
		selenium.click("//html/body/div[@id='toolbar']/table/tbody/tr/td[2]/table/tbody/tr/td[3]/a/img[@id='calendarid']");
		
		// Data
		GregorianCalendar gc = new GregorianCalendar();
		String	Dia = String.valueOf( gc.get( gc.DAY_OF_MONTH ) );
				Dia = ( Dia.length() > 1 ) ? Dia : "0"+Dia; 
		
		String	Mes = String.valueOf( gc.get( gc.MONTH ) + 1 );
		
		String	Ano = String.valueOf( gc.get( gc.YEAR ) );
		
		//Adicionando um Evento
		selenium.open("/index.php?date=" + Ano + Mes + Dia + "&menuaction=calendar.uicalendar.week");
		selenium.click("//img[@title='Nova Entrada']");
		selenium.waitForPageToLoad("30000");
		
		for( Campo cmp : Campo.values() )
		{
			String cmpName = cmp.name();
				 
			if( cmp.getValue().indexOf("addSelection:") > -1 )
			{	
				AddSelection( cmp.getValue(), getValor( cmp.name() ) );
			}
			
			if( cmp.getValue().indexOf("click:") > -1 )
			{
				Click( cmp.getValue() );
			}
			
			if( cmp.getValue().indexOf("select:") > -1 )
			{
				Select( cmp.getValue(), getValor( cmp.name() ) );
			}
			
			if( cmp.getValue().indexOf("type:") > -1 )
			{
				Type( cmp.getValue(), getValor( cmp.name() ) );
			}
		}
		
		selenium.waitForPageToLoad("15000");
		
		// Verifica a hora Inicial e final do Compromisso
		assertTrue( selenium.isTextPresent(Valor.HORA_INICIO.getValue() + ":" + Valor.MINUTO_INICIO.getValue() + 
				 "-" + Valor.HORA_FINAL.getValue() + ":" + Valor.MINUTO_FINAL.getValue()));

		// Verifica o Titulo do Compromisso
		assertTrue( selenium.isTextPresent(Valor.TITULO.getValue()) );
		
		// Verifica a Descricao do Compromisso
		assertTrue( selenium.isTextPresent(Valor.DESCRICAO.getValue()) );

		// Verifica Alarme
		assertTrue( selenium.getHtmlSource().contains("/calendar/templates/default/images/alarm.png"));
		
	}
	
	public String getValor(String cmpName)
	{
		String _return = "";
		
		for( Valor vlr : Valor.values() )
		{
			 String vlrName = vlr.name();
			 
			 if( vlrName.equals( cmpName ) )
			 {
				 _return = vlr.getValue();
			 }
		}
		
		return _return;
	}
	
	public void AddSelection( String locator, String optionLocator )
	{
		selenium.addSelection( locator.substring( 13 , locator.length() ), optionLocator );
	}
	
	public void Click( String locator )
	{
		selenium.click( locator.substring( 6 , locator.length() ) );
	}

	public void Select( String selectLocator, String optionLocator )
	{
		selenium.select( selectLocator.substring( 7 , selectLocator.length() ), optionLocator );
	}

	public void Type( String locator, String value )
	{
		selenium.type( locator.substring( 5 , locator.length() ), value );
	}
	
	@After
	public void tearDown() throws Exception
	{
		selenium.close();
	}
}